/* 
D-Lev logo plate
*/

$fn=100;

// config params:
NZ_D=0.4;				// nozzle dia
NZ_H=0.25;				// nozzle height
// build switches
XY_SCALE=15.385;			// x & y scale
SIMPLE=1;				// just "D-Lev" w/ rings
//
W=6.5;					// width
L=(SIMPLE)?2.25:3;	// length
R=0.5;					// outer radius
H=2;						// height
D=1;						// depth (less than H)
T=0.2;					// edge thickness
HD=3;						// hole diameter
HX=2.75;					// hole x loc

module outline(w=10, l=10, h=1, r=1){
	hull(){	
		x = w/2-r;
		y = l/2-r;
		translate([x,y,0]) cylinder(r=r, h=h);
		translate([-x,y,0]) cylinder(r=r, h=h);
		translate([-x,-y,0]) cylinder(r=r, h=h);
		translate([x,-y,0]) cylinder(r=r, h=h);
	}
}

module plaque(){
	difference(){
		outline(w=W, l=L, h=H, r=R);
		translate([0,0,H-D]) outline(w=W-2*T, l=L-2*T, h=H, r=R-T);
	}
}

module ring(r=1, t=0.1){
	difference(){
		offset(t/2) circle(r=r);
		offset(-t/2) circle(r=r);
	}
}

module rings(x=0, y=0){
	rings = 4;
	rstep = 0.16;
	rstart = 0.6;
	translate([x-0.49,y+0.85,0]){
		t = max(0.05, 2*NZ_D/XY_SCALE);
		for (i=[0:rings-1]){ ring(r=rstart-i*rstep, t=t); }
	}
}

module logo_text(x=0, y=0){
	translate([x-0.5,y,0]) text("D-Le", size=1, font="Neuropol", halign="center");
	translate([x+1.9,y,0]) text("v", size=1, font="Neuropol", halign="center");
	if (!SIMPLE) translate([x,y-0.5,0]) text("Digital theremin", size=0.35, font="Space Age", halign="center");
}	

module all(){
	difference(){
		scale([XY_SCALE,XY_SCALE,1]){
			plaque();
			linear_extrude(H) {
				x = (SIMPLE) ? -0.1 : 0;
				y = (SIMPLE) ? -0.7 : -0.45;
				logo_text(x, y);
				rings(x, y);
			}
		}
	x = XY_SCALE*HX;
	translate([x,0,-0.01]) cylinder(d=HD, h=H+0.02);
	translate([-x,0,-0.01]) cylinder(d=HD, h=H+0.02);
	}
}

all();

echo("dims:", W*XY_SCALE, L*XY_SCALE);

